@@ -1,14 +1,28 @@
+from __future__ import absolute_import
+"""
+Type matchers
+-------------
+.. data:: any_string
+.. data:: any_int
+.. data:: any_float
+.. data:: any_dict
+.. data:: any_list
+
+.. function:: object_with(attribute_name)
+
+	Match an object that has an attribute named `attribute_name`.
+
+"""
 __all__ = [
 	'any_string',
 	'any_int',
 	'any_float',
 	'any_dict',
 	'any_list',
-	'any_',
 	'object_with'
 ]
 
-from base import Matcher
+from .base import Matcher
 
 class TypeMatcher(Matcher):
 	def __init__(self, cls):
@@ -18,7 +32,7 @@ class TypeMatcher(Matcher):
 		return isinstance(other, self.cls)
 	
 	def desc(self):
-		return "Any instance of %s" % (self.cls.__name__,)
+		return "any instance of %s" % (self.cls.__name__,)
 
 class ObjectWithAttribute(Matcher):
 	def __init__(self, attr_name):
@@ -30,7 +44,6 @@ class ObjectWithAttribute(Matcher):
 	def desc(self):
 		return "any object with attribute \"%s\"" % (self.attr_name,)
 
-any_ = TypeMatcher
 any_string = TypeMatcher(str)
 any_int = TypeMatcher(int)
 any_float = TypeMatcher(float)
